Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Auth ¶
func Auth() error
Auth checks if token exists in local config and requests new one if it doesn't
func ListAndPromptBranch ¶
ListAndPromptBranch lists all PRs and prompts to return a branch name
func ListAndPromptBranchByName ¶
ListAndPromptBranchByName lists all remote branches and prompts to return a branch name
Types ¶
type AuthRequest ¶
type AuthRequest struct {
Note string `json:"note"`
Scopes []string `json:"scopes"`
Fingerprint string `json:"fingerprint"`
}
AuthRequest is a structure for authentication request body
type Authorization ¶
Authorization is a body structure of response with token
type GHBranchResponse ¶
type GHBranchResponse struct {
Name string `json:"name"`
}
GHBranchResponse is a structure of GitHub response
func ListBranchesDo ¶
func ListBranchesDo(projectConfig *aws.Project) (prs []GHBranchResponse, err error)
ListBranchesDo makes a GET request to get all remove branches
type GHPRResponse ¶
GHPRResponse is a structure of GitHub response
Click to show internal directories.
Click to hide internal directories.